@@ -50,3 +50,5 @@ OPENID_ID_FIELD = 'openid_identifier'
 SESSION_NAME = 'openid'
 OPENID_GOOGLE_URL = 'https://www.google.com/accounts/o8/id'
 OPENID_YAHOO_URL = 'http://yahoo.com'
+OPENID_LIVEJOURNAL_URL = 'http://%s.livejournal.com'
+OPENID_LIVEJOURNAL_USER_FIELD = 'openid_lj_user'
