@@ -6,19 +6,7 @@ from django.core.urlresolvers import reverse
 from django.contrib.auth import login, REDIRECT_FIELD_NAME
 from django.contrib.auth.decorators import login_required
 
-from .auth import TwitterAuth, FacebookAuth, OpenIdAuth, GoogleAuth, \
-                  YahooAuth, OrkutAuth
-
-
-# Authentication backends
-BACKENDS = {
-    'twitter': TwitterAuth,
-    'facebook': FacebookAuth,
-    'google': GoogleAuth,
-    'yahoo': YahooAuth,
-    'openid': OpenIdAuth,
-    'orkut': OrkutAuth,
-}
+from .auth import get_backend
 
 
 def auth(request, backend):
@@ -31,9 +19,9 @@ def auth(request, backend):
 
 def complete(request, backend):
     """Authentication complete process"""
-    if backend not in BACKENDS:
+    backend = get_backend(backend, request, request.path)
+    if not backend:
         return HttpResponseServerError('Incorrect authentication service')
-    backend = BACKENDS[backend](request, request.path)
     user = backend.auth_complete()
     if user and getattr(user, 'is_active', True):
         login(request, user)
@@ -56,9 +44,9 @@ def associate(request, backend):
 @login_required
 def associate_complete(request, backend):
     """Authentication complete process"""
-    if backend not in BACKENDS:
+    backend = get_backend(backend, request, request.path)
+    if not backend:
         return HttpResponseServerError('Incorrect authentication service')
-    backend = BACKENDS[backend](request, request.path)
     backend.auth_complete(user=request.user)
     url = request.session.pop(REDIRECT_FIELD_NAME, '') or \
           getattr(settings, 'LOGIN_REDIRECT_URL', '')
@@ -67,12 +55,12 @@ def associate_complete(request, backend):
 
 def auth_process(request, backend, complete_url_name, default_final_url):
     """Authenticate using social backend"""
-    if backend not in BACKENDS:
+    redirect = reverse(complete_url_name, args=(backend,))
+    backend = get_backend(backend, request, redirect)
+    if not backend:
         return HttpResponseServerError('Incorrect authentication service')
     request.session[REDIRECT_FIELD_NAME] = request.GET.get(REDIRECT_FIELD_NAME,
                                                            default_final_url)
-    redirect = reverse(complete_url_name, args=(backend,))
-    backend = BACKENDS[backend](request, redirect)
     if backend.uses_redirect:
         return HttpResponseRedirect(backend.auth_url())
     else:
